{# -*- engine:django -*- #}

{% extends "core/base.html" %}

{% load i18n %}
{% load render_table from django_tables2 %}

{% block browser_title %}{% blocktrans %}Group types{% endblocktrans %}{% endblock %}
{% block page_title %}{% blocktrans %}Group types{% endblocktrans %}{% endblock %}

{% block content %}
  <a class="btn green waves-effect waves-light" href="{% url 'create_group_type' %}">
    <i class="material-icons left">add</i>
    {% trans "Create group type" %}
  </a>

  {% render_table group_types_table %}
{% endblock %}
